@@ -12,6 +12,7 @@ use base "Exporter";
 our @EXPORT = (
     qw/
        debug
+       slurp
        /);
 
 our $VERSION = '0.01';
@@ -80,6 +81,23 @@ sub debug {
 
 
 
+=head2 slurp($file)
+
+Read the contents of $file and return it, or undef if the file
+couldn't be opened.
+
+=cut
+sub slurp {
+	my ($file) = @_;
+    open(my $fh, "<", $file) or return undef;
+    local $/;
+    return <$fh>;
+}
+
+
+
+
+
 1;
 
 
